@@ -1,11 +1,10 @@
-import os
 import yaml
 from ..utils import config_path
 
 
-def get_configs(cfg):
+def config(cfg):
     cfg_output = {}
-    cfg = config_path(f"base/{cfg}.yaml")
+    cfg = config_path(f"base/{cfg}")
     with open(cfg) as f:
         cfg_output.update(yaml.load(f, Loader=yaml.FullLoader))
 
